import os
import sys
sys.path.append(os.path.abspath(os.path.join('./grailabsDataCli/scripts')))
import json
from .apiHandler import ApiException, AccessDeniedException, JobCreationException
from .descriptionVerifier import DescriptionVerifier, ValueError, ValueNotDefined, ValueTypeError, JobExeception
from .apiHandler import ApiHandler
from .authHandler import AuthHandler
from pathlib import Path
from datetime import datetime




class JobBuilder:
    def __init__(self, BasePath="http://localhost:4000"):
        self.basePath = BasePath
        self.authHandler = AuthHandler(self.basePath)
        self.apiHandler = ApiHandler(self.basePath)

    def getCredentials(self):
        print("Admin credentials is required")
        email = input("Email: ")
        password = input("Password: ")
        return email, password

    def verifyFilePath(self, value) -> bool:
        if not value:
            raise ValueNotDefined("Dataset path ('src_data')")
        if type(value) != str or not value.strip():
            raise ValueError("Dataset path ('src_data')", value, "String")
        path = Path(value)
        if path and path.is_file():
            return True
        else:
            raise ValueError("Dataset path ('src_data') is not a valid path")

    def addDataToJob(self, name: str, dataPath: str, email=None, password=None, trail=1):
        credentialProvided = email != None and password != None
        if credentialProvided:
            status, message = self.authHandler.authenticate(
                email, password, rememberToken=False)
            if (not status):
                return False, message
            authToken = message
        elif not self.authHandler.isAuthenticated():
            _email, _password = self.getCredentials()
            status, message = self.authHandler.authenticate(_email, _password)
            if (not status):
                return False, message
            authToken = message
        else:
            authToken = self.authHandler.getTokenObj()['auth-token']

        if (not name):
            return False, "Name of the job is required"
        try:
            self.verifyFilePath(dataPath)
            try:
                result = self.apiHandler.extendJob(authToken, name, dataPath)
                return True, result['message']
            except AccessDeniedException as e:
                if (trail == 1 and not credentialProvided):
                    email, password = self.getCredentials()
                    status, message = self.authHandler.authenticate(
                        email, password)
                    if (not status):
                        return False, message
                    return self.addDataToJob(name, dataPath, trail=0)
                else:
                    return False, e.message

            except ApiException as e:
                return False, e.message

        except JobExeception as e:
            return False, e.message

    def createJob(self, desc_path, email=None, password=None, trail=1, automation=False):
        descJobDescHandler = DescriptionVerifier(
            desc_path, readFromSrcDataDefualtLocation=automation)
        credentialProvided = email != None and password != None
        if credentialProvided:
            status, message = self.authHandler.authenticate(
                email, password, rememberToken=False)
            if (not status):
                return False, message
            authToken = message
        elif not self.authHandler.isAuthenticated():
            _email, _password = self.getCredentials()
            status, message = self.authHandler.authenticate(_email, _password)
            if (not status):
                return False, message
            authToken = message
        else:
            authToken = self.authHandler.getTokenObj()['auth-token']

        jobDataObj = descJobDescHandler.getDescConfig()
        if automation:
            timstamp = datetime.timestamp(datetime.now())
            timstampStr = str(timstamp).replace(".", "_")
            jobDataObj.data['name'] = jobDataObj.data['name'] + \
                "_" + timstampStr
        if jobDataObj.verfied:
            try:
                return True, self.apiHandler.createJob(
                    jobDataObj.data, authToken)['message']
            except AccessDeniedException as e:
                if (trail == 1 and not credentialProvided):
                    email, password = self.getCredentials()
                    status, message = self.authHandler.authenticate(
                        email, password)
                    if (not status):
                        return False, message
                    return self.createJob(desc_path, trail=0)
                else:
                    return False, e.message

            except ApiException as e:
                return False, e.message

        else:
            return False, jobDataObj.message


if __name__ == "__main__":
    jd = JobCreator("../job-desc-files/desc.json")
    print(jd.createJob())



import os
import sys
sys.path.append(os.path.abspath(os.path.join('./grailabsDataCli')))
from scripts.jobBuilder import JobBuilder
import argparse
from colorama import Fore, Back, Style

def main():
    try:
        print()
        CLI_DESC = "This tool is needed to extened tasks for an existing job in grailabs-data.com\
      using a command line interface. To extend tasks means to add new data (new tasks)  \
      to an existing job. The CLI tool accepts name of the job to be extended and path to the data file to be added.\n\
      "
        eplilog = "Written by Daniel Zelalem Zewdie.\
    Contact danielzelalemheru@gmail.com"
        argParser = argparse.ArgumentParser(
            description=CLI_DESC, epilog=eplilog, prog="extend_job")
        argParser.add_argument('--name', required=True, type=str,
                               help="The name of the job to be extended, Required")

        argParser.add_argument('--src_data', required=True, type=str,
                               help="Path to a csv dataset to be added, Required")
       
        argParser.add_argument('--email', required=False, type=str,
                               help="Admin email address for grailabs-data account. Optional unless password arg is provided")

        argParser.add_argument('--password', required=False, type=str,
                               help="Admin password for grailabs-data account,  Optional unless email arg is provided")
        
        args = argParser.parse_args()
        name = args.name
        dataPath = args.src_data
        email = args.email
        password = args.password
        if (email):
            if not password:
                print(
                    "--email is provided the following arguments are required: --password")
                sys.exit(0)
        if (password):
            if not email:
                print(
                    "--password is provided the following arguments are required: --email")
                sys.exit(0)

        jc = JobBuilder()
        status, message = jc.addDataToJob(name, dataPath, email, password)
        if (not status):
            logColor = Fore.RED
            prefix = "FAIL"
        else:
            logColor = Fore.GREEN
            prefix = "SUCCESS"
        print(logColor + f"{prefix}: {message}", logColor)
        print("Opreation finished!")
        print()

    except KeyboardInterrupt as e:
        print("Opreation interrupted")



#!/bin/bash
import os
import sys
sys.path.append(os.path.abspath(os.path.join('./grailabsDataCli/scripts')))
from .apiHandler import ApiException
from .apiHandler import ApiHandler
import pickle




class AuthHandler:

    def __init__(self, base, BASE_PATH="http://localhost:4000"
                 ):
        self.apiHandler = ApiHandler(BASE_PATH)
        pass

    def isAuthenticated(self):
        authTokenObj = self.getTokenObj()
        if (not authTokenObj):
            return False
        try:
            if (not authTokenObj['auth-token']):
                return False
            return True
        except KeyError as e:
            return False
        return False

    def getTokenObj(self, fileName: str = 'tokCache'):
        try:
            with open(f"../.{fileName}.pkl", "rb") as f:
                return pickle.load(f)
        except FileNotFoundError:
            return None

    def saveToken(self, token: str, fileName: str = 'tokCache'):
        with open(f"../.{fileName}.pkl", "wb") as f:
            pickle.dump({"auth-token": token}, f)

    def authenticate(self, email, password, rememberToken=True):
        try:
            res = self.apiHandler.loginAsAdmin(email, password)
            token = res['token']
            if (token and rememberToken):
                self.saveToken(token)
            return True, token
        except ApiException as e:
            return False, e.message


if __name__ == "__main__":
    ah = AuthHandler()
    email = "danielzelalemheru@gmail.com"
    password = "Abc123.."
    # print(ah.authenticate(email, password))
    print("val ", ah.isAuthenticated())
    print("val ", ah.getTokenObj())



import requests
import json


class ApiException(Exception):
    pass


class AuthFailedException(ApiException):
    def __init__(self, message="Incorrect email or password"):
        self.message = message
        super().__init__(self.message)


class JobCreationException(ApiException):
    def __init__(self, message=""):
        self.message = message
        super().__init__(self.message)


class JobCreationSchedulingException(ApiException):
    def __init__(self, message=""):
        self.message = message
        super().__init__(self.message)


class AccessDeniedException(ApiException):
    def __init__(self, message=""):
        self.message = message
        super().__init__(self.message)


class NetWorkException(ApiException):
    def __init__(self, message="Network error"):
        self.message = message
        super().__init__(self.message)


class ApiHandler:
    def __init__(self, basePath: str):
        self.basePath = basePath

    def loginAsAdmin(self, email, password, endpoint="/auth/login"):
        payload = {'email': email, 'password': password}
        api_call = self.basePath + endpoint
        try:
            response = requests.post(api_call, json=payload)
            ret = response.json()
            if (not ret['success']):
                raise AuthFailedException(ret['message'])
            return {'message': ret['message'], 'token': ret['data']['token']}
        except requests.exceptions.ConnectionError:
            raise NetWorkException()

    def extendJob(self, authToken: str, jobName: str, dataPath: str, endpoint="/jobs/add_data"):
        try:

            api_call = self.basePath + endpoint

            headers = {"auth-token": authToken}
            files = {'data': ('data.csv', open(dataPath, 'rb'), 'text/csv')}
            payload = {'name': jobName}

            response = requests.post(api_call, headers=headers,
                                     files=files, data=payload)
            ret = response.json()
            if (not ret['success']):
                if (ret['code'] == 403):
                    raise AccessDeniedException(ret['message'])
                    return
                raise JobCreationException(ret['message'])
                return
            return {'message': ret['message']}
            return ret

        except requests.exceptions.ConnectionError:
            raise NetWorkException()

    def scheduleNewJobAutomation(self, email: str, password: str, sec_interval: float, srcData: str,
                                 descPath: str, endpoint="/test"):

        try:

            api_call = self.basePath + endpoint

            files = {
                'desc_file': ('desc.json;', open(descPath, 'rb'), 'application/json;'),
                'src_file': ('src_data.csv;', open(srcData, 'rb'), 'text/csv;'),

            }
            headers = {'content-Type': 'multipart/form-data;boundary=******',
                       'accept': 'application/json'}

            payload = {'email': email,  'password': password, 'sec_interval': sec_interval,
                       }

            response = requests.post(
                api_call, files=files, data=payload)
            ret = response.json()
            if (response.status_code == 422):
                message = getMessageFromError422(ret)
                raise JobCreationSchedulingException(message)
                return
            if (not ret['success']):
                raise JobCreationSchedulingException(ret['message'])
                return
            return {'message': ret['message']}
            return ret

        except requests.exceptions.ConnectionError:
            raise NetWorkException()

    def stopJobCreationAutomation(self, name: str, endpoint="/stopJobCreation"):

        try:
            api_call = self.basePath + endpoint
            payload = {'name': name}

            response = requests.post(
                api_call, json=payload)
            ret = response.json()
            if (response.status_code == 422):
                message = getMessageFromError422(ret)
                raise JobCreationSchedulingException(message)
                return
            if (not ret['success']):
                raise JobCreationSchedulingException(ret['message'])
                return
            return {'message': ret['message']}
            return ret

        except requests.exceptions.ConnectionError:
            raise NetWorkException()
    #

    def rescheduleJobCreationAutomation(self, name: str,  sec_interval: float, endpoint="/reschedule"):

        try:
            api_call = self.basePath + endpoint
            payload = {'name': name, 'sec_interval': sec_interval}

            response = requests.post(
                api_call, json=payload)
            ret = response.json()
            if (response.status_code == 422):
                message = getMessageFromError422(ret)
                raise JobCreationSchedulingException(message)
                return

            if (not ret['success']):
                raise JobCreationSchedulingException(ret['message'])
                return
            return {'message': ret['message']}
            return ret

        except requests.exceptions.ConnectionError:
            raise NetWorkException()

    def createJob(self, jobData, authToken,  endpoint="/jobs/create"):
        try:
            headers = {"auth-token": authToken}
            jobData = jobData
            dataPath = jobData['src_data']
            payload = jobData.copy()
            payload['qa_comments'] = json.dumps(payload['qa_comments'])
            payload.pop('src_data')

            api_call = self.basePath + endpoint

            files = {'data': ('data.csv', open(dataPath, 'rb'), 'text/csv')}
            response = requests.post(
                api_call, headers=headers, files=files, data=payload)
            ret = response.json()
            if (not ret['success']):
                if (ret['code'] == 403):
                    raise AccessDeniedException(ret['message'])
                    return
                raise JobCreationException(ret['message'])
                return
            return {'message': ret['message']}
        except requests.exceptions.ConnectionError:
            raise NetWorkException()

    def getAllJobs(self):
        pass


def getMessageFromError422(errorObj) -> str:
    errorList = errorObj['detail']
    msg = "The following arguments have error\n"
    for error in errorList:
        errorLbl = error['loc'][1]
        errorMsg = error['msg']
        msg += f"  - {errorLbl}: {errorMsg}"
    return msg


if __name__ == "__main__":
    basePath = "http://localhost:4000"
    ah = apiHandler(basePath)
    email = "danielzelalemheru@gmail.com"
    password = "Abc123.."
    print(ah.loginAsAdmin(email, password))



import sys
import os
sys.path.append(os.path.abspath(os.path.join('./grailabsDataCli')))
from scripts.automationClient import AutomationClient
import argparse
from colorama import Fore, Back, Style


def createJobInterface():
    try:
        print()
        CLI_DESC = "This is an automation interfcae for communicating with grailabs-data automation service.\
           This tool is used to  for automating new job creation."
        eplilog = "Written by Daniel Zelalem Zewdie.\
    Contact danielzelalemheru@gmail.com"
        argParser = argparse.ArgumentParser(
                description=CLI_DESC, epilog=eplilog, prog="automate")

        
        argParser.add_argument('--desc', required=True, type=str,
                                help="The path to the job description file, Required")
        argParser.add_argument('--src_data', required=True, type=str,
                                help="The path to the source csv dataset, Required")
        argParser.add_argument('--sec_interval', required=True, type=float,
                                help="The Job excution intervals expressed in number of seconds")
        args = argParser.parse_args()

        args = argParser.parse_args()
        desc_path = args.desc
        src_data = args.src_data
        sec_interval = args.sec_interval

        ac = AutomationClient()
       
        status, message = ac.scheduleNewJobAutomation(
            sec_interval, desc_path, src_data)

        # todo actual automation
        if (not status):
            logColor = Fore.RED
            prefix = "FAIL"
        else:
            logColor = Fore.GREEN
            prefix = "SUCCESS"
        print(logColor + f"{prefix}: {message}", logColor)
        print("Opreation finished!")
        print()


    except KeyboardInterrupt as e:
        print("Opreation interrupted")


def stopJobCreationInterface():
    try:
        print()
        CLI_DESC = "This is an automation interfcae for communicating with grailabs-data automation service.\
           This tool is used to stop a scheduled job creation opreation."
        eplilog = "Written by Daniel Zelalem Zewdie.\
    Contact danielzelalemheru@gmail.com"
        argParser = argparse.ArgumentParser(
            description=CLI_DESC, epilog=eplilog, prog="automate")

        argParser.add_argument('--name', required=True, type=str,
                               help="The prefix name of the job that is scheduled for job creation, Required")

        args = argParser.parse_args()
        name = args.name

        ac = AutomationClient()

        status, message = ac.stopJobCreation(name)   
        if (not status):
            logColor = Fore.RED
            prefix = "FAIL"
        else:
            logColor = Fore.GREEN
            prefix = "SUCCESS"
        print(logColor + f"{prefix}: {message}", logColor)
        print("Opreation finished!")
        print()

    except KeyboardInterrupt as e:
        print("Opreation interrupted")


def rescheduleJobCreationInterface():
    try:
        print()
        CLI_DESC = "This is an automation interfcae for communicating with grailabs-data automation service.\
           This tool is used to reschedule a scheduled job creation opreation."
        eplilog = "Written by Daniel Zelalem Zewdie.\
    Contact danielzelalemheru@gmail.com"
        argParser = argparse.ArgumentParser(
            description=CLI_DESC, epilog=eplilog, prog="automate")

        argParser.add_argument('--name', required=True, type=str,
                               help="The prefix name of the job that is scheduled for job creation, Required")
        
        argParser.add_argument('--sec_interval', required=True, type=float,
                               help="The prefix name of the job that is scheduled for job creation, Required")


        args = argParser.parse_args()
        name = args.name
        sec_interval = args.sec_interval

        ac = AutomationClient()

        status, message = ac.rescheduleJobCreation(name, sec_interval)
        if (not status):
            logColor = Fore.RED
            prefix = "FAIL"
        else:
            logColor = Fore.GREEN
            prefix = "SUCCESS"
        print(logColor + f"{prefix}: {message}", logColor)
        print("Opreation finished!")
        print()

    except KeyboardInterrupt as e:
        print("Opreation interrupted")



import logging


class appLogger:

    def __init__(self, file_name: str, basic_level=logging.INFO):
        # Gets or creates a logger
        logger = logging.getLogger(__name__)

        # set log level
        logger.setLevel(basic_level)

        # define file handler and set formatter
        file_handler = logging.FileHandler(file_name)
        formatter = logging.Formatter(
            '%(asctime)s : %(levelname)s : %(name)s : %(message)s')

        file_handler.setFormatter(formatter)
        logger.addHandler(file_handler)

        self.logger = logger

    def get_app_logger(self) -> logging.Logger:
        return self.logger



import json
from pathlib import Path


class JobExeception(Exception):
    pass


class ValueNotDefined(JobExeception):
    def __init__(self, label: str):
        self.message = f"Value for {label} is required but got nothing or empty"
        super().__init__(self.message)


class ValueTypeError(JobExeception):
    def __init__(self, label: str, value: str, expectedType: str):
        self.message = f"Invalid type found for {label}. Expected type is {expectedType}, but found {type(value)}"
        super().__init__(self.message)


class ValueError(JobExeception):
    def __init__(self, message="Invalid value"):
        self.message = message
        super().__init__(self.message)


class JobDataVerificationWrapper:
    def __init__(self, verfied: bool, data, message):
        self.verfied = verfied
        self.data = data
        self.message = message


class DescriptionVerifier:
    def __init__(self, path: str, readFromSrcDataDefualtLocation=False):
        try:
            self.path = path
            self.readFromSrcDataDefualtLocation = readFromSrcDataDefualtLocation
            with open(path, "r") as f:
                self.config = json.load(f)
        except FileNotFoundError as e:
            e.strerror = "Job Description file not found"
            raise e
        except json.decoder.JSONDecodeError as e:
            self.config = None

    def verify(self) -> bool:
        try:
            self.verifyName(self.config['name'])
            self.verifyInstruction(self.config['instruction'])
            self.verifyQaInstruction(self.config['qa_instruction'])
            self.verifyRedoThreshold(self.config['redo_threshold'])
            self.verifyQaPct(self.config['qa_pct'])
            self.verifyComments(self.config['qa_comments'])
            self.verifyQuota(self.config['quota'])
            self.verifyQaQuota(self.config['qa_quota'])
            if self.readFromSrcDataDefualtLocation:
                srcDataPath = "src_data.csv"
            else:
                srcDataPath = self.config['src_data']

            self.verifyFilePath(srcDataPath)
            self.config['src_data'] = self.actualPathOfSrcData(srcDataPath)

            return True

        except KeyError as e:
            raise ValueNotDefined(e.args[0])
            return False

    def actualPathOfSrcData(self, value):
        actualPath = "./" + str(Path(self.path).parent) + "/" + value
        return actualPath

    def getDescConfig(self) -> JobDataVerificationWrapper:
        if (self.config == None):
            return JobDataVerificationWrapper(False, None, "Job description file is not a valid JSON data")
        try:
            self.verify()
            return JobDataVerificationWrapper(True, self.config, "")
        except JobExeception as e:
            return JobDataVerificationWrapper(False, None, e.message)
            return {"verfied": False, "data": None, "message": e.message}

    def verifyName(self, value) -> bool:
        if not value or not value.strip():
            raise ValueNotDefined("Name ('name')")
        if type(value) != str:
            raise ValueTypeError("Name ('name')", value, "String")
        return True

    def verifyInstruction(self, value) -> bool:
        if not value or not value.strip():
            raise ValueNotDefined("Instruction ('instruction')")
        if type(value) != str:
            raise ValueTypeError(
                "Instruction ('instruction')", value, "String")
        return True

    def verifyQaInstruction(self, value) -> bool:
        if not value or not value.strip():
            raise ValueNotDefined("QA Instruction ('qa_instruction')")
        if type(value) != str:
            raise ValueTypeError(value, "String")
        return True

    def verifyRedoThreshold(self, value) -> bool:
        if not value:
            raise ValueNotDefined("Redo threshold ('redo_threshold')")
        if type(value) != float and type(value) != int:
            raise ValueTypeError(
                "Redo threshold ('redo_threshold')", value, "Integer or float")
        return True

    def verifyQaPct(self, value) -> bool:
        if not value:
            raise ValueNotDefined("QA percentage ('qa_pct')")

        if type(value) != float and type(value) != int:
            raise ValueTypeError("QA percentage ('qa_pct')",
                                 value, "Integer or float")

        if value < 0 or value > 100:
            raise ValueError(
                "QA percentage ('qa_pct') must be in range b/n 0 and 100")

        return True

    def verifyComments(self, value) -> bool:
        if type(value) != list:
            raise ValueTypeError("Comments ('comments')", value, "List")
        for item in value:
            if (type(item) != str or not item.strip()):
                raise ValueTypeError('comment', item, "String")
        return True

    def verifyFilePath(self, value) -> bool:
        if not value:
            raise ValueNotDefined("Dataset path ('src_data')")
        if type(value) != str or not value.strip():
            raise ValueTypeError("Dataset path ('src_data')", value, "String")

        actualPath = self.actualPathOfSrcData(value)
        path = Path(actualPath)
        if path and path.is_file():
            return True
        else:
            raise ValueError("Dataset path ('src_data') is not a valid path")

    def verifyQuota(self, value) -> bool:
        if not value:
            raise ValueNotDefined("Quota ('quota')")
        if type(value) != int:
            raise ValueTypeError("Quota ('quota')", value, "Integer or float")
        if value < 0:
            raise ValueError(
                "Quota ('quota') cant be negative")

    def verifyQaQuota(self, value) -> bool:
        if not value:
            raise ValueNotDefined("QA Quota ('qa_quota')")
        if type(value) != int:
            raise ValueTypeError("QA Quota ('qa_quota')",
                                 value, "Integer or float")
        if value < 0:
            raise ValueError(
                "QA Quota ('qa_quota') cant be negative")


if __name__ == "__main__":
    dv = DescriptionVerifier("../job-desc-files/desc.json")
    print(dv.getDescConfig())



import os
import sys
sys.path.append(os.path.abspath(os.path.join('./grailabsDataCli/scripts')))
from datetime import datetime
from pathlib import Path
from .authHandler import AuthHandler
from .apiHandler import ApiHandler
from .descriptionVerifier import DescriptionVerifier, ValueError, ValueNotDefined, ValueTypeError, JobExeception
from .apiHandler import ApiException, AccessDeniedException



class AutomationClient:
    def __init__(self, BASE_PATH="http://localhost:8000"
                 ):
        self.basePath = BASE_PATH
        self.authHandler = AuthHandler(self.basePath)
        self.apiHandler = ApiHandler(self.basePath)

    def getCredentials(self):
        print("Admin credentials is required")
        email = input("Email: ")
        password = input("Password: ")
        return email, password

    def verifyFilePath(self, value, label) -> bool:
        if not value:
            raise ValueNotDefined(label)
        if type(value) != str or not value.strip():
            raise ValueError(label, value, "String")
        path = Path(value)
        if path and path.is_file():
            return True
        else:
            raise ValueError(f"{label}is not a valid path")

    def scheduleNewJobAutomation(self, sec_interval: float, descPath: str, srcDataPath: str,
                                 email=None, password=None):
        _email, _password = self.getCredentials()
        status, message = self.authHandler.authenticate(
            _email, _password, rememberToken=False)
        if (not status):
            return False, message
        if (not descPath):
            return False, "Path to job description json file is requierd!"
        if (not srcDataPath):
            return False, "Path to csv dataset ('src_data'), that holds the tasks (data) is required"
        if not sec_interval:
            return False, "Duration interval expressed in seconds is required for the automation"

        try:
            self.verifyFilePath(descPath, "Description json file ('desc')")
            self.verifyFilePath(srcDataPath, "Dataset ('src_data')")
            try:
                sec_interval = eval(str(sec_interval))
                if (sec_interval < 0):
                    return False, "Duration interval should be a postive number"
            except Exception as e:
                return False, "Duration interval should be a postive number"

            try:
                result = self.apiHandler.scheduleNewJobAutomation(
                    _email, _password, sec_interval, srcDataPath, descPath)
                return True, result['message']
            except ApiException as e:
                return False, e.message

        except JobExeception as e:
            return False, e.message

    def stopJobCreation(self, name: str, email=None, password=None):
        _email, _password = self.getCredentials()
        status, message = self.authHandler.authenticate(
            _email, _password, rememberToken=False)
        if (not status):
            return False, message
    
        try:
            try:
                result = self.apiHandler.stopJobCreationAutomation(name)
                return True, result['message']
            except ApiException as e:
                return False, e.message

        except JobExeception as e:
            return False, e.message

    def rescheduleJobCreation(self, name: str, sec_interval: float, email=None, password=None):
        _email, _password = self.getCredentials()
        status, message = self.authHandler.authenticate(
            _email, _password, rememberToken=False)
        if (not status):
              return False, message
        
        try:
            sec_interval = eval(str(sec_interval))
            if (sec_interval < 0):
                return False, "Duration interval should be a postive number"
        except Exception as e:
            return False, "Duration interval should be a postive number"

        try:
            try:
                result = self.apiHandler.rescheduleJobCreationAutomation(name, sec_interval)
                return True, result['message']
            except ApiException as e:
                return False, e.message

        except JobExeception as e:
            return False, e.message



from setuptools import setup, find_packages

setup(
    name='grailabsDataCliLib',
    version='1.0.0',
    description='A example Python package',
    url='https://github.com/daniELgrailDev/grailabs-data-cli',
    author='Daniel Zelalem',
    author_email='danielzelalemheru@gmail.com',
    license='BSD 2-clause',
    packages=['grailabsDataCli', 'grailabsDataCli.scripts'],
    install_requires=['requests == 2.27.1'],
    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
